==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Настройка темы курсора LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Выберите тему курсора, которую вы хотите использовать (наведите курсор на область предварительного просмотра для проверки). &lt;b&gt;После изменений сессию LXQt нужно будет перезапустить&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Установить новую тему...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Удалить тему</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Ошибка XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Нельзя удалить активную тему!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt не смог найти ни одной темы курсора. Будет использована тема X11 по умолчанию. LXQt искал в следующих папках:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Показать...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Настройка темы курсора LXQt</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Выберите тему курсора, которую вы хотите использовать (наведите курсор на область предварительного просмотра для проверки). &lt;b&gt;После изменений сессию LXQt нужно будет перезапустить&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Установить новую тему...</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Удалить тему</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Ошибка XCurTheme</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Нельзя удалить активную тему!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt не смог найти ни одной темы курсора. Будет использована тема X11 по умолчанию. LXQt искал в следующих папках:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Показать...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
</context>
</TS>
